@@ -1,4 +1,4 @@
-from boards.cli import main
+from pixBoards.cli import main
 
 if __name__ == "__main__":
     main()
